@@ -92,6 +92,10 @@ Fl_SVG_Image *Fl_SVG_Image_from(const char *data) {
     return new Fl_SVG_Image(NULL, data);
 }
 
+void Fl_SVG_Image_normalize(Fl_SVG_Image *self) {
+    LOCK(self->normalize();)
+}
+
 IMAGE_DEFINE(Fl_BMP_Image)
 
 Fl_BMP_Image *Fl_BMP_Image_new(const char *filename) {
